'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var Q = require('q');
var createError = require('http-errors');
var logger_1 = require("../logger");
function assertGranted(permission) {
    var defer = Q.defer();
    if (!permission.granted) {
        defer.reject(createError(403, "not authorized for user with roles " + permission.allRoles));
    }
    else {
        logger_1.default.trace(permission);
        defer.resolve(permission);
    }
    return defer.promise;
}
exports.assertGranted = assertGranted;
function ifGranted(type, _for, permission, op) {
    if (permission.type && type === permission.type
        && permission.for && _for === permission.for) {
        return op;
    }
    else {
        logger_1.default.trace("not match for " + type + " and " + _for + " in this permission. Returning identity fnc");
        return function (value) { return value; }; //return nop
    }
}
exports.ifGranted = ifGranted;
function ifGrantedForUser(permission, op) {
    return ifGranted('own', 'user', permission, op);
}
exports.ifGrantedForUser = ifGrantedForUser;
function ifGrantedForOrganization(permission, op) {
    return ifGranted('own', 'organization', permission, op);
}
exports.ifGrantedForOrganization = ifGrantedForOrganization;
function ifDefined(func) {
    if (func) {
        return func;
    }
    else {
        return function (value) { return value; }; //return nop
    }
}
exports.ifDefined = ifDefined;
